package com.ynet.life.search.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.search.EXTBankNoIndexSearch;
import com.ynet.life.search.PMSBankNoIndexSearch;
import com.ynet.life.search.RCUBankNoIndexSearch;
import java.util.Iterator;
import java.util.List;

/* loaded from: com_ynet_life_search_action.jar:com/ynet/life/search/action/BankNoSearchAction.class */
public class BankNoSearchAction extends LifeAction {
    private String beginPosFieldName;
    private String showNumFieldName;
    private String totalNumFieldName;
    private String totalHitsFieldName;
    private String queryStringFieldName;
    private String maxResultSize;
    private String bankNoType;

    public String execute(Context context) throws GENEException {
        int beginPos;
        int showNum;
        String queryString = (String) context.get(this.queryStringFieldName);
        if (queryString == null || queryString.equals("")) {
            return "0";
        }
        try {
            beginPos = Integer.parseInt((String) context.get(this.beginPosFieldName));
        } catch (NumberFormatException unused) {
            beginPos = 1;
        }
        try {
            showNum = Integer.parseInt((String) context.get(this.showNumFieldName));
        } catch (NumberFormatException unused2) {
            showNum = 10;
        }
        try {
            int maxSize = Integer.parseInt(this.maxResultSize);
            PMSBankNoIndexSearch pMSBankNoIndexSearch = null;
            if ("1".equals(this.bankNoType)) {
                String indexPath = String.valueOf(LifeStandard.getRootPath()) + LifeStandard.getSelfDefineSettingsValue("pmsBanknoIndexPath");
                pMSBankNoIndexSearch = new PMSBankNoIndexSearch(indexPath, queryString, maxSize);
            } else if ("2".equals(this.bankNoType)) {
                String indexPath2 = String.valueOf(LifeStandard.getRootPath()) + LifeStandard.getSelfDefineSettingsValue("extBanknoIndexPath");
                pMSBankNoIndexSearch = new EXTBankNoIndexSearch(indexPath2, queryString, maxSize);
            } else if ("3".equals(this.bankNoType)) {
                String indexPath3 = String.valueOf(LifeStandard.getRootPath()) + LifeStandard.getSelfDefineSettingsValue("rcuBanknoIndexPath");
                pMSBankNoIndexSearch = new RCUBankNoIndexSearch(indexPath3, queryString, maxSize);
            }
            Iterator it = pMSBankNoIndexSearch.results(beginPos, showNum);
            try {
                context.setDataValue(this.totalNumFieldName, Integer.valueOf(pMSBankNoIndexSearch.resultCount()));
                Trace.logDebug("LifeSearch", "搜索结果总数：" + pMSBankNoIndexSearch.resultCount());
                try {
                    context.setDataValue(this.totalHitsFieldName, Integer.valueOf(pMSBankNoIndexSearch.totalHits()));
                    Trace.logDebug("LifeSearch", "搜索结果命中：" + pMSBankNoIndexSearch.totalHits());
                    try {
                        IndexedCollection bankInfo = (IndexedCollection) context.get("iBankInfo");
                        while (it.hasNext()) {
                            List record = (List) it.next();
                            String unionBankNo = "";
                            String bankName = "";
                            String cityName = "";
                            String provinceName = "";
                            String bankHeadName = "";
                            if ("1".equals(this.bankNoType)) {
                                unionBankNo = (String) record.get(0);
                                bankName = (String) record.get(1);
                                cityName = (String) record.get(4);
                                provinceName = (String) record.get(6);
                                bankHeadName = (String) record.get(8);
                            } else if ("2".equals(this.bankNoType)) {
                                unionBankNo = (String) record.get(0);
                                bankName = (String) record.get(1);
                            } else if ("3".equals(this.bankNoType)) {
                                unionBankNo = (String) record.get(0);
                                bankName = (String) record.get(1);
                                cityName = (String) record.get(3);
                                provinceName = (String) record.get(5);
                            }
                            KeyedCollection singleRecord = new KeyedCollection();
                            singleRecord.addDataField("unionBankNo", unionBankNo);
                            singleRecord.addDataField("bankName", bankName);
                            singleRecord.addDataField("cityName", cityName);
                            singleRecord.addDataField("provinceName", provinceName);
                            singleRecord.addDataField("bankHeadName", bankHeadName);
                            bankInfo.addDataElement(singleRecord);
                        }
                        return "0";
                    } catch (Exception ex) {
                        Trace.logError("LifeAction", "搜索结果异常", ex);
                        throw new GENEException(ex);
                    }
                } catch (Exception e) {
                    Trace.logError("LifeAction", "搜索结果异常", e);
                    throw new GENEException(e);
                }
            } catch (Exception e2) {
                Trace.logError("LifeAction", "输出结果数据异常", e2);
                throw new TranFailException(e2);
            }
        } catch (Exception ex2) {
            Trace.logError("LifeAction", "联行号搜索异常", ex2);
            throw new GENEException(ex2);
        }
    }

    public String getBeginPosFieldName() {
        return this.beginPosFieldName;
    }

    public void setBeginPosFieldName(String beginPosFieldName) {
        this.beginPosFieldName = beginPosFieldName;
    }

    public String getShowNumFieldName() {
        return this.showNumFieldName;
    }

    public void setShowNumFieldName(String showNumFieldName) {
        this.showNumFieldName = showNumFieldName;
    }

    public String getTotalNumFieldName() {
        return this.totalNumFieldName;
    }

    public void setTotalNumFieldName(String totalNumFieldName) {
        this.totalNumFieldName = totalNumFieldName;
    }

    public String getTotalHitsFieldName() {
        return this.totalHitsFieldName;
    }

    public void setTotalHitsFieldName(String totalHitsFieldName) {
        this.totalHitsFieldName = totalHitsFieldName;
    }

    public String getQueryStringFieldName() {
        return this.queryStringFieldName;
    }

    public void setQueryStringFieldName(String queryStringFieldName) {
        this.queryStringFieldName = queryStringFieldName;
    }

    public String getMaxResultSize() {
        return this.maxResultSize;
    }

    public void setMaxResultSize(String maxResultSize) {
        this.maxResultSize = maxResultSize;
    }

    public String getBankNoType() {
        return this.bankNoType;
    }

    public void setBankNoType(String bankNoType) {
        this.bankNoType = bankNoType;
    }
}
